import type { Job } from "./job";
import type { RegularStep, RunStep, StepBase } from "./step";
import type { Workflow } from "./workflow";
/**
 * Base class for all validators.
 * This class provides common functionality for error management
 * and validation processes.
 */
export declare abstract class Validator {
    private _errors;
    /**
     * Validates the current instance. This method should be implemented
     * by subclasses to perform specific validations.
     */
    abstract validate(): void;
    /**
     * Gets the list of validation errors collected during validation.
     */
    get errors(): string[];
    /**
     * Adds multiple error messages to the validator's error list.
     *
     * @param errors - An array of error messages to be added.
     */
    protected addErrors(errors: string[]): void;
    /**
     * Checks if a required property is set. If not, adds an error message
     * to the error list.
     *
     * @param property - The property to check.
     * @param name - The name of the property for the error message.
     */
    protected checkRequired(property: unknown, name: string): void;
}
/**
 * Validator for Workflow instances.
 * Validates properties specific to a workflow configuration.
 */
export declare class WorkflowValidator extends Validator {
    private readonly workflow;
    constructor(workflow: Workflow);
    /**
     * Validates the workflow's environment variables.
     */
    validate(): void;
}
/**
 * Validator for Job instances.
 * Validates properties specific to a job configuration within a workflow.
 */
export declare class JobValidator extends Validator {
    private readonly job;
    constructor(job: Job);
    /**
     * Validates the job's ID format, environment variables, and checks
     * if the job has steps defined.
     */
    validate(): void;
}
/**
 * Validator for StepBase instances.
 * Validates properties shared by all step types within a job.
 */
export declare class StepBaseValidator extends Validator {
    private readonly step;
    constructor(step: StepBase);
    /**
     * Validates the step's ID format and environment variables.
     */
    validate(): void;
}
/**
 * Validator for RunStep instances.
 * Validates properties specific to a run step, such as the shell type.
 */
export declare class RunStepValidator extends Validator {
    private readonly step;
    constructor(step: RunStep);
    /**
     * Validates the run step's properties.
     */
    validate(): void;
}
/**
 * Validator for RegularStep instances.
 * Validates properties specific to a regular step.
 */
export declare class RegularStepValidator extends Validator {
    private readonly step;
    constructor(step: RegularStep);
    /**
     * Validates the regular step's properties.
     */
    validate(): void;
}
